function qfcttest(s)

% Copyright, Jan Larsen, IMM, DTU, Feb. 2003

% two component Gaussian mixture
% surrogate data set
close all;
N=1000;
s=abs(s);
pk1=0.3;
pk2=1-pk1;
N1=round(N*pk1);
N2=N-N1;
x=[randn(N1,1);(randn(N2,1)+s)];
p=pk1*exp(-x.^2/2)+pk2*exp(-(x-s).^2/2);
p=p/sqrt(2*pi);

figure(1)
%hist(x)
h=plot(x,log(p),'.');
set(h,'LineWidth',1.8);

%P_L(t) estimated from surrogate data
figure(2)
tval=sort(log(p));
%tval=sort((p));
h=plot(tval,(0:(N-1))/N,'b');
set(h,'LineWidth',1.8);
hold on
h=xlabel('t');
set(h,'FontSize',19);
h=ylabel('P_L(t)');
set(h,'FontSize',19);
h=title(sprintf('s=%2.2g',s));
set(h,'FontSize',19);

%Approximate analytival distribution P_L(t)
tapp=linspace(min(tval),max(tval),500);


C1=log(pk1)-0.5*log(2*pi);
PL=1-chi2cdfn(2*(C1-tapp),1);
C2=log(pk2)-0.5*log(2*pi);
PL=pk1*PL+pk2*(1-chi2cdfn(2*(C2-tapp),1));

h=plot(tapp,PL,'r--');
set(h,'LineWidth',1.8);
h=legend('sample dist','appromimation');
set(h,'FontSize',19);
set(gca,'FontSize',16);
hold off





%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function p = chi2cdfn(x,v)
%CHI2CDF Chi-square cumulative distribution function.
%   P = CHI2CDFN(X,V) returns the chi-square cumulative distribution
%   function with V degrees of freedom at the values in X.
%   The chi-square density function with V degrees of freedom,
%   is the same as a gamma density function with parameters V/2 and 2.
%
%   The size of P is the common size of X and V. A scalar input   
%   functions as a constant matrix of the same size as the other input.    

%   References:
%      [1]  M. Abramowitz and I. A. Stegun, "Handbook of Mathematical
%      Functions", Government Printing Office, 1964, 26.4.
%
%   Notice that we do not check if the degree of freedom parameter is integer
%   or not. In most cases, it should be an integer. Numerically, non-integer 
%   values still gives a numerical answer, thus, we keep them.

%   Copyright 1993-2002 The MathWorks, Inc. 
%   $Revision: 2.10 $  $Date: 2002/01/17 21:30:14 $

if   nargin < 2, 
    error('Requires two input arguments.');
end

[errorcode x v] = distchck(2,x,v);

if errorcode > 0
    error('Requires non-scalar arguments to match in size.');
end
    
% Call the gamma distribution function. 
p = gamcdfn(x,v/2,2);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function p = gamcdfn(x,a,b)
%GAMCDF Gamma cumulative distribution function.
%   P = GAMCDFN(X,A,B) returns the gamma cumulative distribution
%   function with parameters A and B at the values in X.
%
%   The size of P is the common size of the input arguments. A scalar input  
%   functions as a constant matrix of the same size as the other inputs.    
%
%   Some references refer to the gamma distribution with a single
%   parameter. This corresponds to the default of B = 1. 
%
%   GAMMAINC does computational work.

%   References:
%      [1]  L. Devroye, "Non-Uniform Random Variate Generation", 
%      Springer-Verlag, 1986. p. 401.
%      [2]  M. Abramowitz and I. A. Stegun, "Handbook of Mathematical
%      Functions", Government Printing Office, 1964, 26.1.32.

%   Copyright 1993-2002 The MathWorks, Inc. 
%   $Revision: 2.12 $  $Date: 2002/01/17 21:30:39 $

if nargin < 3, 
    b = 1; 
end

if nargin < 2, 
    error('Requires at least two input arguments.'); 
end

[errorcode x a b] = distchck(3,x,a,b);

if errorcode > 0
    error('Requires non-scalar arguments to match in size.');
end

% Initialize P to zero.
p = zeros(size(x));

%   Return NaN if the arguments are outside their respective limits.
p(a <= 0 | b <= 0) = NaN;

k = find(x > 0 & ~(a <= 0 | b <= 0));
if any(k), 
    p(k) = gammainc(x(k) ./ b(k),a(k));
end

% Make sure that round-off errors never make P greater than 1.
p(p > 1) = 1;

% If we have NaN or Inf, fix if possible
k = ~isfinite(p);
if (any(k)), p(x>=sqrt(realmax)) = 1; end
